@@ -1020,6 +1020,42 @@ const char *medium_xpm[] = {
 
 /* --------------------------------------------------- */
 
+const char *medium_edit_xpm[] = {
+/* width height num_colors chars_per_pixel */
+"    50    20        7            1",
+/* colors */
+". c #000000",
+"# c #a05020",
+"- c #608060",
+"0 c #80c080",
+"+ c #a0a0a0",
+"* c #ffffff",
+"  none",
+/* pixels */
+"                                                  ",
+"  ################                                ",
+"  ################                                ",
+"  #..##########..#                                ",
+"  #..##########..#                                ",
+"  ################                                ",
+"  ################                                ",
+"  #..##########..#   ++++++++++++++++++++++++++++ ",
+"  #..##########..#   +0000000**.**00000000000000- ",
+"  ################   +0000000**.**00000000000000- ",
+"  ################   +0000000**.**00000000000000- ",
+"  #..##########..#   +0000000**.**00000000000000- ",
+"  #..##########..#   ---------------------------- ",
+"  ################                                ",
+"  ################                                ",
+"  #..##########..#                                ",
+"  #..##########..#                                ",
+"  ################                                ",
+"  ################                                ",
+"                                                  "
+};
+
+/* --------------------------------------------------- */
+
 const char *medium_delete_xpm[] = {
 /* width height num_colors chars_per_pixel */
 "    20    20        4            1",
